@@ -13,12 +13,6 @@
 #'   variation of information. If not provided, equal population of precincts
 #'   will be assumed, i.e. the VI will be computed with respect to the precincts
 #'   themselves, and not the population.
-#' @param district_membership Deprecated, use plans. A matrix with one row for each precinct and one
-#' column for each map. Required.
-#' @param pop The vector of precinct populations. Used only if computing
-#'   variation of information. If not provided, equal population of precincts
-#'   will be assumed, i.e. the VI will be computed with respect to the precincts
-#'   themselves, and not the population.
 #'
 #' @details
 #' Hamming distance measures the number of different precinct assignments
@@ -55,19 +49,7 @@
 #' @concept analyze
 #' @export
 redist.distances <- function(plans, measure = "Hamming",
-                             ncores = 1, total_pop = NULL,
-                             district_membership, pop) {
-
-
-    if(!missing(pop)){
-        total_pop <- pop
-        .Deprecated(new = 'total_pop', old = 'pop')
-    }
-    if(!missing(district_membership)){
-        plans <- district_membership
-        .Deprecated('plans')
-    }
-
+                             ncores = 1, total_pop = NULL) {
 
     supported = c("all", "Hamming", "Manhattan", "Euclidean", "variation of information")
     # fuzzy matching
@@ -88,7 +70,7 @@ redist.distances <- function(plans, measure = "Hamming",
         `%oper%` <- `%do%`
     } else {
         `%oper%` <- `%dopar%`
-        cl <- makeCluster(nc, setup_strategy = 'sequential')
+        cl <- makeCluster(nc, setup_strategy = 'sequential', methods=FALSE)
         registerDoParallel(cl)
         on.exit(stopCluster(cl))
     }
@@ -176,5 +158,44 @@ plan_distances = function(plans, measure="variation of information", ncores=1) {
     redist.distances(get_plans_matrix(plans), measure, ncores=ncores, total_pop=pop)[[1]]
 }
 
+#' Calculate the diversity of a set of plans
+#'
+#' Returns the off-diagonal elements of the variation of information distance
+#' matrix for a sample of plans, which can be used as a diagnostic measure to
+#' assess the diversity of a set of plans. If there are many values close to zero,
+#' then the sample has many similar plans and may not be a good approximation
+#' to the target distribution.
+#'
+#' @param plans a \code{\link{redist_plans}} object.
+#' @param n_max the maximum number of plans to sample in computing the
+#'   distances. Larger numbers will have less sampling error but will require
+#'   more computation time.
+#' @param ncores the number of cores to use in computing the distances.
+#'
+#' @return A numeric vector of off-diagonal variation of information distances.
+#'
+#' @examples
+#' data(iowa)
+#' ia <- redist_map(iowa, existing_plan=cd_2010, pop_tol=0.01)
+#' plans <- redist_smc(ia, 100, silent=TRUE)
+#' hist(plans_diversity(plans))
+#'
+#' @concept analyze
+#' @export
+plans_diversity = function(plans, n_max=100, ncores=1) {
+    m = get_plans_matrix(plans)
+    n_eval = min(n_max, ncol(m))
+    idx = sample.int(ncol(m), n_eval, replace=FALSE)
+
+    ndists = max(m[, 1])
+    pop = attr(plans, "prec_pop")
+    if (is.null(pop))
+        stop("Precinct population must be stored in `prec_pop` attribute of `plans` object")
+
+    dists = redist.distances(m[, idx], "variation of information",
+                             ncores=ncores, total_pop=pop)$VI
+    0.5 * dists[upper.tri(dists)] / log(ndists)
+}
+
 
 utils::globalVariables(names = "map")
