@@ -10,7 +10,7 @@
 #' }
 #' @noRd
 preproc.shp <- function(shp){
-  if(!is.null(shp)){  
+  if(!is.null(shp)){
     if('SpatialPolygonsDataFrame' %in% class(shp)){
       shp <- shp %>%  st_as_sf()
     } else if(!('sf' %in% class(shp))){
@@ -45,38 +45,32 @@ preproc.adj <- function(shp, adj){
 
 
 #' Return a random subgraph of a shape
-#' 
+#'
 #' @description `random.subgraph` returns a random subset of the shp provided
-#' 
+#'
 #' @details Snowball sampling with backtracking
-#' 
+#'
 #' @param shp sf object or SpatialPolygonsDataFrame
 #' @param n number of edges to sample. n must be a positive integer.
 #' @param adj Optional. zero indexed adjacency list.
-#' @param adjacency Deprecated, use adj. Optional. zero indexed adjacency list.
 #'
 #' @return sf dataframe with n rows
 #' @export
 #' @importFrom dplyr union setdiff slice %>%
-#' 
-#' 
-redist.random.subgraph <- function(shp, n, adj = NULL, adjacency){
-  if(!missing(adjacency)){
-    .Deprecated(new = 'adj', old = 'adjacency')
-    adj <- adjacency
-  }
-  
+#'
+#'
+redist.random.subgraph <- function(shp, n, adj = NULL){
   # Check input:
   shp <- preproc.shp(shp)
   adj <- preproc.adj(shp, adj)
-  
+
   if(n < 1){
     stop('Please provide "n" as a positive integer')
   }
   if(n > nrow(shp)){
     stop('"n" has more entries than shp. Please provide smaller "n"')
   }
-  
+
   # create helper objects
   index <- rep(NA_real_, n)
   index[1] <- sample.int(nrow(shp), 1)
@@ -88,16 +82,16 @@ redist.random.subgraph <- function(shp, n, adj = NULL, adjacency){
     i <- i + 1
     # pick one from connected objects
     index[i] <- sample(candidates, 1)
-    
+
     # add new candidate options and ignore existing ones
-    candidates <- dplyr::union(candidates, adj[[index[i]]]+1) %>% dplyr::setdiff(index) 
+    candidates <- dplyr::union(candidates, adj[[index[i]]]+1) %>% dplyr::setdiff(index)
   }
-  
+
   rlist <- list(shp = shp %>% dplyr::slice(sort(index)),
                 keep_rows = sort(index)
-    
+
   )
   return(rlist)
-  
+
 }
 
