@@ -13,7 +13,7 @@
 #' boundary constraints.
 #'
 #' This function draws nearly-independent samples from a specific target measure,
-#' controlled by the \code{popcons}, \code{compactness}, \code{constraints}, and
+#' controlled by the \code{pop_tol}, \code{compactness}, \code{constraints}, and
 #' \code{constraint_fn} parameters.
 #'
 #' Key to ensuring good performance is monitoring the efficiency of the resampling
@@ -40,10 +40,10 @@
 #'   districts.
 #'   * \code{current}, a vector containing district assignments for
 #'   the current map.
-#' * \code{vra}: a list with three entries:
-#'   * \code{strength}, a number controlling the strength of the Voting Rights Act
-#'   (VRA) constraint, with higher values prioritizing majority-minority districts
-#'   over other considerations.
+#' * \code{hinge}: a list with three entries:
+#'   * \code{strength}, a number controlling the strength of the constraint, with
+#'   higher values prioritizing districts with group populations at least
+#'   \code{tgts_min} over other considerations.
 #'   * \code{tgts_min}, the target percentage(s) of minority voters in minority
 #'   opportunity districts. Defaults to \code{c(0.55)}.
 #'   * \code{min_pop}, A vector containing the minority population of each
@@ -53,7 +53,7 @@
 #'   to avoid pairing up incumbents.
 #'   * \code{incumbents}, a vector of precinct indices, one for each incumbent's
 #'   home address.
-#' * \code{vra_old}: a list with five entries, which may be set up using
+#' * \code{vra}: a list with five entries, which may be set up using
 #'   \code{\link{redist.constraint.helper}}:
 #'   * \code{strength}, a number controlling the strength of the Voting Rights Act
 #'   (VRA) constraint, with higher values prioritizing majority-minority districts
@@ -67,18 +67,22 @@
 #'   minority percentage; higher values are more tolerant. Defaults to 1.5
 #'   * \code{min_pop}, A vector containing the minority population of each
 #'   geographic unit.
+#' * \code{multisplits}: a list with one entry:
+#'   * \code{strength}, a number controlling the tendency of the generated districts
+#'   to avoid splitting counties multiple times.
 #'
 #' All constraints are fed into a Gibbs measure, with coefficients on each
 #' constraint set by the corresponding \code{strength} parameters.
+#' The strength can be any real number, with zero corresponding to no constraint.
 #' The \code{status_quo} constraint adds a term measuring the variation of
 #' information distance between the plan and the reference, rescaled to \[0, 1\].
-#' The \code{vra} constraint takes a list of target minority percentages. It
+#' The \code{hinge} constraint takes a list of target minority percentages. It
 #' matches each district to its nearest target percentage, and then applies a
 #' penalty of the form \eqn{\sqrt{max(0, tgt - minpct)}}, summing across
 #' districts. This penalizes districts which are below their target population.
 #' The \code{incumbency} constraint adds a term counting the number of districts
 #' containing paired-up incumbents.
-#' The \code{vra_old} constraint adds a term of the form
+#' The \code{vra} constraint  (not recommended) adds a term of the form
 #' \eqn{(|tgtvramin-minpct||tgtvraother-minpct|)^{powvra})}, which
 #' encourages districts to have minority percentages near either \code{tgt_vra_min}
 #' or \code{tgt_vra_other}. This can be visualized with
@@ -88,36 +92,41 @@
 #' @param map A \code{\link{redist_map}} object.
 #' @param nsims The number of samples to draw.
 #' @param counties A vector containing county (or other administrative or
-#' geographic unit) labels for each unit, which may be integers ranging from 1
-#' to the number of counties, or a factor or character vector.  If provided, the
-#' algorithm will only generate maps which split up to \code{ndists-1} counties.
-#' If no county-split constraint is desired, this parameter should be left blank.
+#'   geographic unit) labels for each unit, which may be integers ranging from 1
+#'   to the number of counties, or a factor or character vector.  If provided,
+#'   the algorithm will only generate maps which split up to \code{ndists-1}
+#'   counties. If no county-split constraint is desired, this parameter should
+#'   be left blank.
 #' @param compactness Controls the compactness of the generated districts, with
-#' higher values preferring more compact districts. Must be nonnegative. See the
-#' 'Details' section for more information, and computational considerations.
+#'   higher values preferring more compact districts. Must be nonnegative. See
+#'   the 'Details' section for more information, and computational
+#'   considerations.
 #' @param constraints A list containing information on constraints to implement.
-#' See the 'Details' section for more information.
+#'   See the 'Details' section for more information.
 #' @param resample Whether to perform a final resampling step so that the
-#' generated plans can be used immediately.  Set this to \code{FALSE} to perform
-#' direct importance sampling estimates, or to adjust the weights manually.
+#'   generated plans can be used immediately.  Set this to \code{FALSE} to
+#'   perform direct importance sampling estimates, or to adjust the weights
+#'   manually.
 #' @param constraint_fn A function which takes in a matrix where each column is
 #'  a redistricting plan and outputs a vector of log-weights, which will be
 #'  added the the final weights.
 #' @param adapt_k_thresh The threshold value used in the heuristic to select a
-#' value \code{k_i} for each splitting iteration. Set to 0.9999 or 1 if
-#' the algorithm does not appear to be sampling from the target distribution.
-#' Must be between 0 and 1.
+#'   value \code{k_i} for each splitting iteration. Set to 0.9999 or 1 if the
+#'   algorithm does not appear to be sampling from the target distribution. Must
+#'   be between 0 and 1.
 #' @param seq_alpha The amount to adjust the weights by at each resampling step;
-#' higher values prefer exploitation, while lower values prefer exploration.
-#' Must be between 0 and 1.
+#'   higher values prefer exploitation, while lower values prefer exploration.
+#'   Must be between 0 and 1.
 #' @param truncate Whether to truncate the importance sampling weights at the
-#' final step by \code{trunc_fn}.  Recommended if \code{compactness} is not 1.
-#' Truncation only applied if \code{resample=TRUE}.
-#' @param trunc_fn A function which takes in a vector of weights and returns
-#' a truncated vector. If \code{\link[loo]{loo}} package is installed (strongly
-#' recommended), will default to Pareto-smoothed Importance Sampling (PSIS)
-#' rather than naive truncation.
-#' @param pop_temper The strength of the automatic population tempering.
+#'   final step by \code{trunc_fn}.  Recommended if \code{compactness} is not 1.
+#'   Truncation only applied if \code{resample=TRUE}.
+#' @param trunc_fn A function which takes in a vector of weights and returns a
+#'   truncated vector. If \code{\link[loo]{loo}} package is installed (strongly
+#'   recommended), will default to Pareto-smoothed Importance Sampling (PSIS)
+#'   rather than naive truncation.
+#' @param pop_temper The strength of the automatic population tempering. Try
+#'   values of 0.01-0.05 to start if the algorithm gets stuck on the final few
+#'   splits.
 #' @param ref_name a name for the existing plan, which will be added as a
 #'   reference plan, or \code{FALSE} to not include the initial plan in the
 #'   output. Defaults to the column name of the existing plan.
@@ -186,6 +195,7 @@ redist_smc = function(map, nsims, counties=NULL, compactness=1, constraints=list
     }
 
     # Other constraints
+    constraints = eval_tidy(enquo(constraints), map)
     proc = process_smc_ms_constr(constraints, V)
     constraints = proc$constraints
     n_current = max(constraints$status_quo$current)
@@ -197,15 +207,20 @@ redist_smc = function(map, nsims, counties=NULL, compactness=1, constraints=list
     pop_bounds = attr(map, "pop_bounds")
     pop = map[[attr(map, "pop_col")]]
     ndists = attr(map, "ndists")
+    if (any(pop >= get_target(map)))
+        stop("Units ", which(pop >= get_target(map)),
+             " have population larger than the district target.\n",
+             "Redistricting impossible.")
 
     lp = rep(0, nsims)
     plans = smc_plans(nsims, adj, counties, pop, ndists, pop_bounds[2],
                       pop_bounds[1], pop_bounds[3], compactness,
                       constraints$status_quo$strength, constraints$status_quo$current, n_current,
-                      constraints$vra_old$strength, constraints$vra_old$tgt_vra_min,
-                      constraints$vra_old$tgt_vra_other, constraints$vra_old$pow_vra, proc$min_pop,
-                      constraints$vra$strength, constraints$vra$tgts_min,
+                      constraints$vra$strength, constraints$vra$tgt_vra_min,
+                      constraints$vra$tgt_vra_other, constraints$vra$pow_vra, proc$min_pop,
+                      constraints$hinge$strength, constraints$hinge$tgts_min,
                       constraints$incumbency$strength, constraints$incumbency$incumbents,
+                      constraints$multisplits$strength,
                       lp, adapt_k_thresh, seq_alpha, pop_temper, verbosity);
 
 
@@ -230,7 +245,7 @@ redist_smc = function(map, nsims, counties=NULL, compactness=1, constraints=list
         plans = plans[, sample(nsims, nsims, replace=T, prob=mod_wgt), drop=FALSE]
     }
 
-    if (n_eff/nsims <= 0.05)
+    if (!is.nan(n_eff) && n_eff/nsims <= 0.05)
         warning("Less than 5% resampling efficiency. Consider weakening constraints and/or adjusting `seq_alpha`.")
 
     out = new_redist_plans(plans, map, "smc", wgt, resample,
@@ -260,11 +275,12 @@ redist_smc = function(map, nsims, counties=NULL, compactness=1, constraints=list
 process_smc_ms_constr = function(constraints, V) {
     defaults = list(
         status_quo = list(strength=0, current=rep(1, V)),
-        vra = list(strength=0, tgts_min=0.55, min_pop=NULL),
-        vra_old = list(strength=0, tgt_vra_min=0.55, tgt_vra_other=0.25,
-                       pow_vra=1.5, min_pop=integer()),
+        hinge = list(strength=0, tgts_min=0.55, min_pop=NULL),
+        vra = list(strength=0, tgt_vra_min=0.55, tgt_vra_other=0.25,
+                   pow_vra=1.5, min_pop=integer()),
         incumbency = list(strength=0, incumbents=integer()),
-        splits = list(strength=0)
+        splits = list(strength=0),
+        multisplits = list(strength=0)
     )
 
     for (type in names(constraints)) {
@@ -277,12 +293,12 @@ process_smc_ms_constr = function(constraints, V) {
         defaults$status_quo$current = defaults$status_quo$current + 1
 
     min_pop = rep(0, V)
-    if (defaults$vra$strength > 0) {
-        if (defaults$vra_old$strength > 0)
+    if (defaults$hinge$strength > 0) {
+        if (defaults$vra$strength > 0)
             stop("Specify one of `vra` or `vra_old` constraints, not both")
+        min_pop = defaults$hinge$min_pop
+    } else if (defaults$vra$strength > 0) {
         min_pop = defaults$vra$min_pop
-    } else if (defaults$vra_old$strength > 0) {
-        min_pop = defaults$vra_old$min_pop
     }
     if (length(min_pop) != V)
         stop("Length of minority population vector must match the number of units.")
@@ -300,8 +316,8 @@ process_smc_ms_constr = function(constraints, V) {
 #' @return numeric vector
 #'
 #' @export
-#' 
-#' @examples 
+#'
+#' @examples
 #' redist_quantile_trunc(c(1,2,3,4))
-#' 
+#'
 redist_quantile_trunc = function(x) pmin(x, quantile(x, 1 - length(x)^(-0.5)))
