@@ -1,6 +1,8 @@
+skip_on_os('solaris')
+
 test_that("SMC runs without errors", {
     N = 20
-    res = redist_smc(fl_map, N, silent=T)
+    res = redist_smc(fl_map, N, silent=TRUE)
 
     expect_s3_class(res, "redist_plans")
 })
@@ -40,7 +42,7 @@ test_that("Not egregiously incorrect sampling accuracy (5-prec)", {
     g = list(c(1L, 4L), c(0L, 2L, 4L), c(1L, 3L, 4L), c(2L, 4L), c(0L, 1L, 2L, 3L))
     g_pop = c(2, 1, 1, 1, 1)
     map = redist_map(pop=g_pop, ndists=2, pop_tol=0.5, adj=g)
-    out = redist_smc(map, 20e3, compactness=0, adapt_k_thresh=1, resample=F, silent=T)
+    out = redist_smc(map, 20e3, compactness=0, adapt_k_thresh=1, resample=FALSE, silent=TRUE)
     types = apply(as.matrix(out), 2, function(x) 1L + (x[1] == x[2]))
     wgts = weights(out)
     avg = weighted.mean(types, wgts)
@@ -56,7 +58,7 @@ test_that("Not egregiously incorrect sampling accuracy (25-prec)", {
     log_st_ref = round(log_st_map(adj, ref_plans, rep(1L, 25), 3L), 5)
 
     out = redist_smc(set_pop_tol(fl_map, 0.01), 6000, compactness=0,
-                     adapt_k_thresh=0.99, seq_alpha=0.3, resample=F, silent=T) %>%
+                     adapt_k_thresh=0.99, seq_alpha=0.3, resample=FALSE, silent=TRUE) %>%
         suppressWarnings() # efficiency
     log_st = round(log_st_map(adj, as.matrix(out), rep(1L, 25), 3L), 5)
     types = match(log_st, log_st_ref)
@@ -73,7 +75,7 @@ test_that("Not egregiously incorrect sampling accuracy (25-prec)", {
 test_that("Precise population bounds are enforced", {
     map2 = fl_map
     attr(map2, "pop_bounds") = c(52e3, 58e3, 60e3)
-    res = redist_smc(map2, 20, silent=T)
+    res = redist_smc(map2, 20, silent=TRUE)
     distr_pop = apply(as.matrix(res), 2, function(x) tapply(pop, x, sum))
     expect_true(all(apply(distr_pop, 2, max) <= 60e3))
     expect_true(all(apply(distr_pop, 2, min) >= 52e3))
